==> qtjambi-qt3drender-5.15.5-sources.jar: io/qt/qt3d/render/QProximityFilter.java <==
package io.qt.qt3d.render;


/**
 * <p>Select entities which are within a distance threshold of a target entity</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html">Qt3DRender::QProximityFilter</a></p>
 */
public class QProximityFilter extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QProximityFilter.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#distanceThreshold-prop">Qt3DRender::QProximityFilter::distanceThresholdChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="distanceThreshold")
    public final Signal1<@io.qt.QtPrimitiveType Float> distanceThresholdChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#entity-prop">Qt3DRender::QProximityFilter::entityChanged(Qt3DCore::QEntity*)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtPropertyNotify(name="entity")
    public final Signal1<io.qt.qt3d.core.QEntity> entityChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QProximityFilter(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QProximityFilter() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QProximityFilter(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QProximityFilter instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#distanceThreshold-prop">Qt3DRender::QProximityFilter::distanceThreshold()const</a></p>
     */
    @io.qt.QtPropertyReader(name="distanceThreshold")
    @io.qt.QtUninvokable
    public final float distanceThreshold(){
        return distanceThreshold_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float distanceThreshold_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#entity-prop">Qt3DRender::QProximityFilter::entity()const</a></p>
     */
    @io.qt.QtPropertyReader(name="entity")
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QEntity entity(){
        return entity_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QEntity entity_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#distanceThreshold-prop">Qt3DRender::QProximityFilter::setDistanceThreshold(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="distanceThreshold")
    public final void setDistanceThreshold(float distanceThreshold){
        setDistanceThreshold_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), distanceThreshold);
    }
    
    private native void setDistanceThreshold_native_float(long __this__nativeId, float distanceThreshold);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#entity-prop">Qt3DRender::QProximityFilter::setEntity(Qt3DCore::QEntity*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="entity")
    @SuppressWarnings({"exports"})
    public final void setEntity(io.qt.qt3d.core.QEntity entity){
        setEntity_native_Qt3DCore_QEntity_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(entity));
    }
    
    private native void setEntity_native_Qt3DCore_QEntity_ptr(long __this__nativeId, long entity);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QProximityFilter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QProximityFilter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QProximityFilter instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QProximityFilter.java <==
package io.qt.qt3d.render;


/**
 * <p>Select entities which are within a distance threshold of a target entity</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html">Qt3DRender::QProximityFilter</a></p>
 */
public class QProximityFilter extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QProximityFilter.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#distanceThreshold-prop">Qt3DRender::QProximityFilter::distanceThresholdChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="distanceThreshold")
    public final Signal1<@io.qt.QtPrimitiveType Float> distanceThresholdChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#entity-prop">Qt3DRender::QProximityFilter::entityChanged(Qt3DCore::QEntity*)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtPropertyNotify(name="entity")
    public final Signal1<io.qt.qt3d.core.QEntity> entityChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QProximityFilter(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QProximityFilter() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QProximityFilter(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QProximityFilter instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#distanceThreshold-prop">Qt3DRender::QProximityFilter::distanceThreshold()const</a></p>
     */
    @io.qt.QtPropertyReader(name="distanceThreshold")
    @io.qt.QtUninvokable
    public final float distanceThreshold(){
        return distanceThreshold_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float distanceThreshold_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#entity-prop">Qt3DRender::QProximityFilter::entity()const</a></p>
     */
    @io.qt.QtPropertyReader(name="entity")
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QEntity entity(){
        return entity_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QEntity entity_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#distanceThreshold-prop">Qt3DRender::QProximityFilter::setDistanceThreshold(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="distanceThreshold")
    public final void setDistanceThreshold(float distanceThreshold){
        setDistanceThreshold_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), distanceThreshold);
    }
    
    private native void setDistanceThreshold_native_float(long __this__nativeId, float distanceThreshold);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qproximityfilter.html#entity-prop">Qt3DRender::QProximityFilter::setEntity(Qt3DCore::QEntity*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="entity")
    @SuppressWarnings({"exports"})
    public final void setEntity(io.qt.qt3d.core.QEntity entity){
        setEntity_native_Qt3DCore_QEntity_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(entity));
    }
    
    private native void setEntity_native_Qt3DCore_QEntity_ptr(long __this__nativeId, long entity);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QProximityFilter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QProximityFilter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QProximityFilter instance, QDeclarativeConstructor constructor);
    
}
